@@ -8,7 +8,7 @@ class Series(Base):
             'filename': filename,
         }
 
-        return self._do_post('/program_video/submit', data).get('id', -1)
+        return self._do_post('program_video/submit', data).get('id', -1)
 
     def submit_by_huashu(self, *, id:str, source:str, bucket_name:str, realpath:str, filename:str):
         data = {
@@ -19,7 +19,7 @@ class Series(Base):
             'filename': filename,
         }
 
-        return self._do_post('/program_video/huashu/submit', data).get('id', -1)
+        return self._do_post('program_video/huashu/submit', data).get('id', -1)
 
     def add_urls(self, program_id:int, urls):
         data = {
@@ -27,7 +27,7 @@ class Series(Base):
             'urls':["{}||{}".format(item['url'], item['title']) for item in urls],
         }
 
-        return self._do_post('/program_video/add_urls', data).get('result', None)
+        return self._do_post('program_video/add_urls', data).get('result', None)
 
     def submit_by_copy(self, *, program_id:str, realpath:str, filename:str):
         data = {
@@ -36,6 +36,6 @@ class Series(Base):
             'filename': filename,
         }
 
-        return self._do_post('/program_video/submit_by_copy', data).get('id', -1)
+        return self._do_post('program_video/submit_by_copy', data).get('id', -1)
 
         
\ No newline at end of file
